==> battledeck-1.13.4.tgz: package/readme.md <==
Battledeck
==========


<a href='https://www.npmjs.com/package/battledeck'>
    <img src='https://img.shields.io/npm/v/battledeck.svg?link=https://www.npmjs.com/package/battledeck&?link=https://www.npmjs.com/package/battledeck' alt='NPM Version' /> 
</a> <a href='https://npm-stat.com/charts.html?package=battledeck'>
    <img src='https://img.shields.io/npm/dt/battledeck.svg' alt='NPM Downloads'/>
</a> <a href='https://opensource.org/licenses/MIT'>
    <img src='https://img.shields.io/npm/l/battledeck.svg' alt='License MIT'/>
</a> <a href='https://david-dm.org/JKerney-HunterIndustries/battledeck'>
    <img src='https://david-dm.org/JKerney-HunterIndustries/battledeck.svg' alt='Dependencies' />
</a>

---

**Install:** `npm i -g battledeck`

**Run:** In directory with images type `battledeck`

## Summary
Battledeck an easy to use program for usinging images as slides for "[Powerpoint Karaoke](https://en.wikipedia.org/wiki/PowerPoint_Karaoke)". You **_MUST_** have a directory of your own images since no images are provided.

## [More detailed documentation can be found here](http://bit.ly/battledeckDocs)

### Suported Image Types
* .jpg
* .jpeg
* .png
* .gif

## Aguments
Battledeck takes an optional parameter to specify the directory with the images.

`battledeck ./images`

Battledeck also takes a -? to better explain arguments

`battledeck -?`<br/>
`battledeck --help`

## Usage
Spacebar 
* Start
* Advance Slide
* Reshuffles slide deck

Esc
* End Presentation

## To Quit

* Click the "Shutdown Link"
* http://localhost:8713/end
* In console press `Ctrl + C`

## License

[MIT license](http://opensource.org/licenses/MIT).

==> battledeck-1.14.2.tgz: package/readme.md <==
Battledeck
==========


<a href='https://www.npmjs.com/package/battledeck'>
    <img src='https://img.shields.io/npm/v/battledeck.svg?link=https://www.npmjs.com/package/battledeck&?link=https://www.npmjs.com/package/battledeck' alt='NPM Version' /> 
</a> <a href='https://npm-stat.com/charts.html?package=battledeck'>
    <img src='https://img.shields.io/npm/dt/battledeck.svg' alt='NPM Downloads'/>
</a> <a href='https://opensource.org/licenses/MIT'>
    <img src='https://img.shields.io/npm/l/battledeck.svg' alt='License MIT'/>
</a> <a href='https://david-dm.org/JKerney-HunterIndustries/battledeck'>
    <img src='https://david-dm.org/JKerney-HunterIndustries/battledeck.svg' alt='Dependencies' />
</a>

---

**Install:** `npm i -g battledeck`

**Run:** In directory with images type `battledeck`

## Summary
Battledeck an easy to use program for using images as slides for "[Powerpoint Karaoke](https://en.wikipedia.org/wiki/PowerPoint_Karaoke)". You **_MUST_** have a directory of your own images since no images are provided.

## [More detailed documentation can be found here](http://bit.ly/battledeckDocs)

### Suported Image Types
* .jpg
* .jpeg
* .png
* .gif

## Arguments
Battledeck takes an optional parameter to specify the directory with the images.

`battledeck ./images`

Battledeck also takes a -? to better explain arguments

`battledeck -?`<br/>
`battledeck --help`

## Usage
Spacebar 
* Start
* Advance Slide
* Reshuffles slide deck

Esc
* End Presentation

## To Quit

* Click the "Shutdown Link"
* http://localhost:8713/end
* In console press `Ctrl + C`

## License

[MIT license](http://opensource.org/licenses/MIT).
